@@ -1,5 +1,7 @@
 """
-Main interface for amplifybackend service client
+Type annotations for amplifybackend service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -10,13 +12,14 @@ Usage::
     client: AmplifyBackendClient = boto3.client("amplifybackend")
     ```
 """
+import sys
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_amplifybackend.literals import ListBackendJobsPaginatorName
 from mypy_boto3_amplifybackend.paginator import ListBackendJobsPaginator
-from mypy_boto3_amplifybackend.type_defs import (
+
+from .type_defs import (
     BackendAPIResourceConfigTypeDef,
     CloneBackendResponseTypeDef,
     CreateBackendAPIResponseTypeDef,
@@ -47,6 +50,12 @@ from mypy_boto3_amplifybackend.type_defs import (
     UpdateBackendJobResponseTypeDef,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = ("AmplifyBackendClient",)
 
 
@@ -68,7 +77,8 @@ class Exceptions:
 
 class AmplifyBackendClient:
     """
-    [AmplifyBackend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -76,14 +86,16 @@ class AmplifyBackendClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def clone_backend(
         self, AppId: str, BackendEnvironmentName: str, TargetEnvironmentName: str
     ) -> CloneBackendResponseTypeDef:
         """
-        [Client.clone_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        [Show boto3-stubs documentation](./client.md#clone-backend)
         """
 
     def create_backend(
@@ -95,7 +107,8 @@ class AmplifyBackendClient:
         ResourceName: str = None,
     ) -> CreateBackendResponseTypeDef:
         """
-        [Client.create_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        [Show boto3-stubs documentation](./client.md#create-backend)
         """
 
     def create_backend_api(
@@ -106,7 +119,8 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> CreateBackendAPIResponseTypeDef:
         """
-        [Client.create_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        [Show boto3-stubs documentation](./client.md#create-backend-api)
         """
 
     def create_backend_auth(
@@ -117,26 +131,30 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> CreateBackendAuthResponseTypeDef:
         """
-        [Client.create_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        [Show boto3-stubs documentation](./client.md#create-backend-auth)
         """
 
     def create_backend_config(
         self, AppId: str, BackendManagerAppId: str = None
     ) -> CreateBackendConfigResponseTypeDef:
         """
-        [Client.create_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        [Show boto3-stubs documentation](./client.md#create-backend-config)
         """
 
     def create_token(self, AppId: str) -> CreateTokenResponseTypeDef:
         """
-        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        [Show boto3-stubs documentation](./client.md#create-token)
         """
 
     def delete_backend(
         self, AppId: str, BackendEnvironmentName: str
     ) -> DeleteBackendResponseTypeDef:
         """
-        [Client.delete_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        [Show boto3-stubs documentation](./client.md#delete-backend)
         """
 
     def delete_backend_api(
@@ -147,26 +165,30 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> DeleteBackendAPIResponseTypeDef:
         """
-        [Client.delete_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        [Show boto3-stubs documentation](./client.md#delete-backend-api)
         """
 
     def delete_backend_auth(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> DeleteBackendAuthResponseTypeDef:
         """
-        [Client.delete_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        [Show boto3-stubs documentation](./client.md#delete-backend-auth)
         """
 
     def delete_token(self, AppId: str, SessionId: str) -> DeleteTokenResponseTypeDef:
         """
-        [Client.delete_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        [Show boto3-stubs documentation](./client.md#delete-token)
         """
 
     def generate_backend_api_models(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GenerateBackendAPIModelsResponseTypeDef:
         """
-        [Client.generate_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        [Show boto3-stubs documentation](./client.md#generate-backend-api-models)
         """
 
     def generate_presigned_url(
@@ -177,14 +199,16 @@ class AmplifyBackendClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_backend(
         self, AppId: str, BackendEnvironmentName: str = None
     ) -> GetBackendResponseTypeDef:
         """
-        [Client.get_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        [Show boto3-stubs documentation](./client.md#get-backend)
         """
 
     def get_backend_api(
@@ -195,33 +219,38 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> GetBackendAPIResponseTypeDef:
         """
-        [Client.get_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        [Show boto3-stubs documentation](./client.md#get-backend-api)
         """
 
     def get_backend_api_models(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAPIModelsResponseTypeDef:
         """
-        [Client.get_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        [Show boto3-stubs documentation](./client.md#get-backend-api-models)
         """
 
     def get_backend_auth(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAuthResponseTypeDef:
         """
-        [Client.get_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        [Show boto3-stubs documentation](./client.md#get-backend-auth)
         """
 
     def get_backend_job(
         self, AppId: str, BackendEnvironmentName: str, JobId: str
     ) -> GetBackendJobResponseTypeDef:
         """
-        [Client.get_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        [Show boto3-stubs documentation](./client.md#get-backend-job)
         """
 
     def get_token(self, AppId: str, SessionId: str) -> GetTokenResponseTypeDef:
         """
-        [Client.get_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        [Show boto3-stubs documentation](./client.md#get-token)
         """
 
     def list_backend_jobs(
@@ -235,19 +264,22 @@ class AmplifyBackendClient:
         Status: str = None,
     ) -> ListBackendJobsResponseTypeDef:
         """
-        [Client.list_backend_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        [Show boto3-stubs documentation](./client.md#list-backend-jobs)
         """
 
     def remove_all_backends(
         self, AppId: str, CleanAmplifyApp: bool = None
     ) -> RemoveAllBackendsResponseTypeDef:
         """
-        [Client.remove_all_backends documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        [Show boto3-stubs documentation](./client.md#remove-all-backends)
         """
 
     def remove_backend_config(self, AppId: str) -> RemoveBackendConfigResponseTypeDef:
         """
-        [Client.remove_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        [Show boto3-stubs documentation](./client.md#remove-backend-config)
         """
 
     def update_backend_api(
@@ -258,7 +290,8 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> UpdateBackendAPIResponseTypeDef:
         """
-        [Client.update_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        [Show boto3-stubs documentation](./client.md#update-backend-api)
         """
 
     def update_backend_auth(
@@ -269,14 +302,16 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> UpdateBackendAuthResponseTypeDef:
         """
-        [Client.update_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        [Show boto3-stubs documentation](./client.md#update-backend-auth)
         """
 
     def update_backend_config(
         self, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = None
     ) -> UpdateBackendConfigResponseTypeDef:
         """
-        [Client.update_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        [Show boto3-stubs documentation](./client.md#update-backend-config)
         """
 
     def update_backend_job(
@@ -288,12 +323,13 @@ class AmplifyBackendClient:
         Status: str = None,
     ) -> UpdateBackendJobResponseTypeDef:
         """
-        [Client.update_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        [Show boto3-stubs documentation](./client.md#update-backend-job)
         """
 
     def get_paginator(
-        self, operation_name: ListBackendJobsPaginatorName
+        self, operation_name: Literal["list_backend_jobs"]
     ) -> ListBackendJobsPaginator:
         """
-        [Paginator.ListBackendJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)[Show boto3-stubs documentation](./paginators.md#listbackendjobspaginator)
         """
