@@ -1,5 +1,7 @@
 """
-Main interface for amplifybackend service client paginators.
+Type annotations for amplifybackend service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -20,17 +22,14 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_amplifybackend.type_defs import (
-    ListBackendJobsResponseTypeDef,
-    PaginatorConfigTypeDef,
-)
+from .type_defs import ListBackendJobsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListBackendJobsPaginator",)
 
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBackendJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)[Show boto3-stubs documentation](./paginators.md#listbackendjobspaginator)
     """
 
     def paginate(
@@ -43,5 +42,6 @@ class ListBackendJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBackendJobsResponseTypeDef]:
         """
-        [ListBackendJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listbackendjobspaginator)
         """
