@@ -1,5 +1,7 @@
 """
-Main interface for amplifybackend service type definitions.
+Type annotations for amplifybackend service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -12,7 +14,7 @@ Usage::
 import sys
 from typing import List
 
-from mypy_boto3_amplifybackend.literals import (
+from .literals import (
     AdditionalConstraintsElement,
     AuthResources,
     DeliveryMethod,
@@ -23,11 +25,14 @@ from mypy_boto3_amplifybackend.literals import (
     OAuthScopesElement,
     RequiredSignUpAttributesElement,
     ResolutionStrategy,
-    Service,
     SignInMethod,
     Status,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -41,27 +46,16 @@ __all__ = (
     "BackendAPIResourceConfigTypeDef",
     "BackendAuthSocialProviderConfigTypeDef",
     "BackendJobRespObjTypeDef",
+    "CloneBackendResponseTypeDef",
+    "CreateBackendAPIResponseTypeDef",
     "CreateBackendAuthForgotPasswordConfigTypeDef",
     "CreateBackendAuthIdentityPoolConfigTypeDef",
     "CreateBackendAuthMFAConfigTypeDef",
     "CreateBackendAuthOAuthConfigTypeDef",
     "CreateBackendAuthPasswordPolicyConfigTypeDef",
     "CreateBackendAuthResourceConfigTypeDef",
-    "CreateBackendAuthUserPoolConfigTypeDef",
-    "EmailSettingsTypeDef",
-    "LoginAuthConfigReqObjTypeDef",
-    "SettingsTypeDef",
-    "SmsSettingsTypeDef",
-    "SocialProviderSettingsTypeDef",
-    "UpdateBackendAuthForgotPasswordConfigTypeDef",
-    "UpdateBackendAuthIdentityPoolConfigTypeDef",
-    "UpdateBackendAuthMFAConfigTypeDef",
-    "UpdateBackendAuthOAuthConfigTypeDef",
-    "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-    "UpdateBackendAuthUserPoolConfigTypeDef",
-    "CloneBackendResponseTypeDef",
-    "CreateBackendAPIResponseTypeDef",
     "CreateBackendAuthResponseTypeDef",
+    "CreateBackendAuthUserPoolConfigTypeDef",
     "CreateBackendConfigResponseTypeDef",
     "CreateBackendResponseTypeDef",
     "CreateTokenResponseTypeDef",
@@ -69,6 +63,7 @@ __all__ = (
     "DeleteBackendAuthResponseTypeDef",
     "DeleteBackendResponseTypeDef",
     "DeleteTokenResponseTypeDef",
+    "EmailSettingsTypeDef",
     "GenerateBackendAPIModelsResponseTypeDef",
     "GetBackendAPIModelsResponseTypeDef",
     "GetBackendAPIResponseTypeDef",
@@ -77,12 +72,22 @@ __all__ = (
     "GetBackendResponseTypeDef",
     "GetTokenResponseTypeDef",
     "ListBackendJobsResponseTypeDef",
+    "LoginAuthConfigReqObjTypeDef",
     "PaginatorConfigTypeDef",
     "RemoveAllBackendsResponseTypeDef",
     "RemoveBackendConfigResponseTypeDef",
+    "SettingsTypeDef",
+    "SmsSettingsTypeDef",
+    "SocialProviderSettingsTypeDef",
     "UpdateBackendAPIResponseTypeDef",
+    "UpdateBackendAuthForgotPasswordConfigTypeDef",
+    "UpdateBackendAuthIdentityPoolConfigTypeDef",
+    "UpdateBackendAuthMFAConfigTypeDef",
+    "UpdateBackendAuthOAuthConfigTypeDef",
+    "UpdateBackendAuthPasswordPolicyConfigTypeDef",
     "UpdateBackendAuthResourceConfigTypeDef",
     "UpdateBackendAuthResponseTypeDef",
+    "UpdateBackendAuthUserPoolConfigTypeDef",
     "UpdateBackendConfigResponseTypeDef",
     "UpdateBackendJobResponseTypeDef",
 )
@@ -104,12 +109,19 @@ BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
 
 BackendAPIAuthTypeTypeDef = TypedDict(
     "BackendAPIAuthTypeTypeDef",
-    {"Mode": Mode, "Settings": "BackendAPIAppSyncAuthSettingsTypeDef"},
+    {
+        "Mode": Mode,
+        "Settings": "BackendAPIAppSyncAuthSettingsTypeDef",
+    },
     total=False,
 )
 
 BackendAPIConflictResolutionTypeDef = TypedDict(
-    "BackendAPIConflictResolutionTypeDef", {"ResolutionStrategy": ResolutionStrategy}, total=False
+    "BackendAPIConflictResolutionTypeDef",
+    {
+        "ResolutionStrategy": ResolutionStrategy,
+    },
+    total=False,
 )
 
 BackendAPIResourceConfigTypeDef = TypedDict(
@@ -126,11 +138,20 @@ BackendAPIResourceConfigTypeDef = TypedDict(
 )
 
 BackendAuthSocialProviderConfigTypeDef = TypedDict(
-    "BackendAuthSocialProviderConfigTypeDef", {"ClientId": str, "ClientSecret": str}, total=False
+    "BackendAuthSocialProviderConfigTypeDef",
+    {
+        "ClientId": str,
+        "ClientSecret": str,
+    },
+    total=False,
 )
 
 _RequiredBackendJobRespObjTypeDef = TypedDict(
-    "_RequiredBackendJobRespObjTypeDef", {"AppId": str, "BackendEnvironmentName": str}
+    "_RequiredBackendJobRespObjTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+    },
 )
 _OptionalBackendJobRespObjTypeDef = TypedDict(
     "_OptionalBackendJobRespObjTypeDef",
@@ -152,209 +173,6 @@ class BackendJobRespObjTypeDef(
     pass
 
 
-_RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef", {"DeliveryMethod": DeliveryMethod}
-)
-_OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthForgotPasswordConfigTypeDef",
-    {"EmailSettings": "EmailSettingsTypeDef", "SmsSettings": "SmsSettingsTypeDef"},
-    total=False,
-)
-
-
-class CreateBackendAuthForgotPasswordConfigTypeDef(
-    _RequiredCreateBackendAuthForgotPasswordConfigTypeDef,
-    _OptionalCreateBackendAuthForgotPasswordConfigTypeDef,
-):
-    pass
-
-
-CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
-    "CreateBackendAuthIdentityPoolConfigTypeDef",
-    {"IdentityPoolName": str, "UnauthenticatedLogin": bool},
-)
-
-_RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthMFAConfigTypeDef", {"MFAMode": MFAMode}
-)
-_OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthMFAConfigTypeDef", {"Settings": "SettingsTypeDef"}, total=False
-)
-
-
-class CreateBackendAuthMFAConfigTypeDef(
-    _RequiredCreateBackendAuthMFAConfigTypeDef, _OptionalCreateBackendAuthMFAConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthOAuthConfigTypeDef",
-    {
-        "OAuthGrantType": OAuthGrantType,
-        "OAuthScopes": List[OAuthScopesElement],
-        "RedirectSignInURIs": List[str],
-        "RedirectSignOutURIs": List[str],
-    },
-)
-_OptionalCreateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthOAuthConfigTypeDef",
-    {"DomainPrefix": str, "SocialProviderSettings": "SocialProviderSettingsTypeDef"},
-    total=False,
-)
-
-
-class CreateBackendAuthOAuthConfigTypeDef(
-    _RequiredCreateBackendAuthOAuthConfigTypeDef, _OptionalCreateBackendAuthOAuthConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef", {"MinimumLength": float}
-)
-_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
-    {"AdditionalConstraints": List[AdditionalConstraintsElement]},
-    total=False,
-)
-
-
-class CreateBackendAuthPasswordPolicyConfigTypeDef(
-    _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef,
-    _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef,
-):
-    pass
-
-
-_RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthResourceConfigTypeDef",
-    {
-        "AuthResources": AuthResources,
-        "Service": Service,
-        "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
-    },
-)
-_OptionalCreateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthResourceConfigTypeDef",
-    {"IdentityPoolConfigs": "CreateBackendAuthIdentityPoolConfigTypeDef"},
-    total=False,
-)
-
-
-class CreateBackendAuthResourceConfigTypeDef(
-    _RequiredCreateBackendAuthResourceConfigTypeDef, _OptionalCreateBackendAuthResourceConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
-    {
-        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElement],
-        "SignInMethod": SignInMethod,
-        "UserPoolName": str,
-    },
-)
-_OptionalCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthUserPoolConfigTypeDef",
-    {
-        "ForgotPassword": "CreateBackendAuthForgotPasswordConfigTypeDef",
-        "Mfa": "CreateBackendAuthMFAConfigTypeDef",
-        "OAuth": "CreateBackendAuthOAuthConfigTypeDef",
-        "PasswordPolicy": "CreateBackendAuthPasswordPolicyConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateBackendAuthUserPoolConfigTypeDef(
-    _RequiredCreateBackendAuthUserPoolConfigTypeDef, _OptionalCreateBackendAuthUserPoolConfigTypeDef
-):
-    pass
-
-
-EmailSettingsTypeDef = TypedDict(
-    "EmailSettingsTypeDef", {"EmailMessage": str, "EmailSubject": str}, total=False
-)
-
-LoginAuthConfigReqObjTypeDef = TypedDict(
-    "LoginAuthConfigReqObjTypeDef",
-    {
-        "AwsCognitoIdentityPoolId": str,
-        "AwsCognitoRegion": str,
-        "AwsUserPoolsId": str,
-        "AwsUserPoolsWebClientId": str,
-    },
-    total=False,
-)
-
-SettingsTypeDef = TypedDict(
-    "SettingsTypeDef", {"MfaTypes": List[MfaTypesElement], "SmsMessage": str}, total=False
-)
-
-SmsSettingsTypeDef = TypedDict("SmsSettingsTypeDef", {"SmsMessage": str}, total=False)
-
-SocialProviderSettingsTypeDef = TypedDict(
-    "SocialProviderSettingsTypeDef",
-    {
-        "Facebook": "BackendAuthSocialProviderConfigTypeDef",
-        "Google": "BackendAuthSocialProviderConfigTypeDef",
-        "LoginWithAmazon": "BackendAuthSocialProviderConfigTypeDef",
-    },
-    total=False,
-)
-
-UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "UpdateBackendAuthForgotPasswordConfigTypeDef",
-    {
-        "DeliveryMethod": DeliveryMethod,
-        "EmailSettings": "EmailSettingsTypeDef",
-        "SmsSettings": "SmsSettingsTypeDef",
-    },
-    total=False,
-)
-
-UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
-    "UpdateBackendAuthIdentityPoolConfigTypeDef", {"UnauthenticatedLogin": bool}, total=False
-)
-
-UpdateBackendAuthMFAConfigTypeDef = TypedDict(
-    "UpdateBackendAuthMFAConfigTypeDef",
-    {"MFAMode": MFAMode, "Settings": "SettingsTypeDef"},
-    total=False,
-)
-
-UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "UpdateBackendAuthOAuthConfigTypeDef",
-    {
-        "DomainPrefix": str,
-        "OAuthGrantType": OAuthGrantType,
-        "OAuthScopes": List[OAuthScopesElement],
-        "RedirectSignInURIs": List[str],
-        "RedirectSignOutURIs": List[str],
-        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
-    },
-    total=False,
-)
-
-UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-    {"AdditionalConstraints": List[AdditionalConstraintsElement], "MinimumLength": float},
-    total=False,
-)
-
-UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "UpdateBackendAuthUserPoolConfigTypeDef",
-    {
-        "ForgotPassword": "UpdateBackendAuthForgotPasswordConfigTypeDef",
-        "Mfa": "UpdateBackendAuthMFAConfigTypeDef",
-        "OAuth": "UpdateBackendAuthOAuthConfigTypeDef",
-        "PasswordPolicy": "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-    },
-    total=False,
-)
-
 CloneBackendResponseTypeDef = TypedDict(
     "CloneBackendResponseTypeDef",
     {
@@ -381,6 +199,128 @@ CreateBackendAPIResponseTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef",
+    {
+        "DeliveryMethod": DeliveryMethod,
+    },
+)
+_OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthForgotPasswordConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthForgotPasswordConfigTypeDef(
+    _RequiredCreateBackendAuthForgotPasswordConfigTypeDef,
+    _OptionalCreateBackendAuthForgotPasswordConfigTypeDef,
+):
+    pass
+
+
+CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
+    "CreateBackendAuthIdentityPoolConfigTypeDef",
+    {
+        "IdentityPoolName": str,
+        "UnauthenticatedLogin": bool,
+    },
+)
+
+_RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthMFAConfigTypeDef",
+    {
+        "MFAMode": MFAMode,
+    },
+)
+_OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthMFAConfigTypeDef",
+    {
+        "Settings": "SettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthMFAConfigTypeDef(
+    _RequiredCreateBackendAuthMFAConfigTypeDef, _OptionalCreateBackendAuthMFAConfigTypeDef
+):
+    pass
+
+
+_RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthOAuthConfigTypeDef",
+    {
+        "OAuthGrantType": OAuthGrantType,
+        "OAuthScopes": List[OAuthScopesElement],
+        "RedirectSignInURIs": List[str],
+        "RedirectSignOutURIs": List[str],
+    },
+)
+_OptionalCreateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthOAuthConfigTypeDef",
+    {
+        "DomainPrefix": str,
+        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthOAuthConfigTypeDef(
+    _RequiredCreateBackendAuthOAuthConfigTypeDef, _OptionalCreateBackendAuthOAuthConfigTypeDef
+):
+    pass
+
+
+_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef",
+    {
+        "MinimumLength": float,
+    },
+)
+_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
+    {
+        "AdditionalConstraints": List[AdditionalConstraintsElement],
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthPasswordPolicyConfigTypeDef(
+    _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef,
+    _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef,
+):
+    pass
+
+
+_RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthResourceConfigTypeDef",
+    {
+        "AuthResources": AuthResources,
+        "Service": Literal["COGNITO"],
+        "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
+    },
+)
+_OptionalCreateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthResourceConfigTypeDef",
+    {
+        "IdentityPoolConfigs": "CreateBackendAuthIdentityPoolConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthResourceConfigTypeDef(
+    _RequiredCreateBackendAuthResourceConfigTypeDef, _OptionalCreateBackendAuthResourceConfigTypeDef
+):
+    pass
+
+
 CreateBackendAuthResponseTypeDef = TypedDict(
     "CreateBackendAuthResponseTypeDef",
     {
@@ -394,9 +334,40 @@ CreateBackendAuthResponseTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
+    {
+        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElement],
+        "SignInMethod": SignInMethod,
+        "UserPoolName": str,
+    },
+)
+_OptionalCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthUserPoolConfigTypeDef",
+    {
+        "ForgotPassword": "CreateBackendAuthForgotPasswordConfigTypeDef",
+        "Mfa": "CreateBackendAuthMFAConfigTypeDef",
+        "OAuth": "CreateBackendAuthOAuthConfigTypeDef",
+        "PasswordPolicy": "CreateBackendAuthPasswordPolicyConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthUserPoolConfigTypeDef(
+    _RequiredCreateBackendAuthUserPoolConfigTypeDef, _OptionalCreateBackendAuthUserPoolConfigTypeDef
+):
+    pass
+
+
 CreateBackendConfigResponseTypeDef = TypedDict(
     "CreateBackendConfigResponseTypeDef",
-    {"AppId": str, "BackendEnvironmentName": str, "JobId": str, "Status": str},
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+        "Status": str,
+    },
     total=False,
 )
 
@@ -415,7 +386,12 @@ CreateBackendResponseTypeDef = TypedDict(
 
 CreateTokenResponseTypeDef = TypedDict(
     "CreateTokenResponseTypeDef",
-    {"AppId": str, "ChallengeCode": str, "SessionId": str, "Ttl": str},
+    {
+        "AppId": str,
+        "ChallengeCode": str,
+        "SessionId": str,
+        "Ttl": str,
+    },
     total=False,
 )
 
@@ -459,7 +435,20 @@ DeleteBackendResponseTypeDef = TypedDict(
 )
 
 DeleteTokenResponseTypeDef = TypedDict(
-    "DeleteTokenResponseTypeDef", {"IsSuccess": bool}, total=False
+    "DeleteTokenResponseTypeDef",
+    {
+        "IsSuccess": bool,
+    },
+    total=False,
+)
+
+EmailSettingsTypeDef = TypedDict(
+    "EmailSettingsTypeDef",
+    {
+        "EmailMessage": str,
+        "EmailSubject": str,
+    },
+    total=False,
 )
 
 GenerateBackendAPIModelsResponseTypeDef = TypedDict(
@@ -476,7 +465,12 @@ GenerateBackendAPIModelsResponseTypeDef = TypedDict(
 )
 
 GetBackendAPIModelsResponseTypeDef = TypedDict(
-    "GetBackendAPIModelsResponseTypeDef", {"Models": str, "Status": Status}, total=False
+    "GetBackendAPIModelsResponseTypeDef",
+    {
+        "Models": str,
+        "Status": Status,
+    },
+    total=False,
 )
 
 GetBackendAPIResponseTypeDef = TypedDict(
@@ -533,28 +527,90 @@ GetBackendResponseTypeDef = TypedDict(
 
 GetTokenResponseTypeDef = TypedDict(
     "GetTokenResponseTypeDef",
-    {"AppId": str, "ChallengeCode": str, "SessionId": str, "Ttl": str},
+    {
+        "AppId": str,
+        "ChallengeCode": str,
+        "SessionId": str,
+        "Ttl": str,
+    },
     total=False,
 )
 
 ListBackendJobsResponseTypeDef = TypedDict(
     "ListBackendJobsResponseTypeDef",
-    {"Jobs": List["BackendJobRespObjTypeDef"], "NextToken": str},
+    {
+        "Jobs": List["BackendJobRespObjTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+LoginAuthConfigReqObjTypeDef = TypedDict(
+    "LoginAuthConfigReqObjTypeDef",
+    {
+        "AwsCognitoIdentityPoolId": str,
+        "AwsCognitoRegion": str,
+        "AwsUserPoolsId": str,
+        "AwsUserPoolsWebClientId": str,
+    },
     total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
 )
 
 RemoveAllBackendsResponseTypeDef = TypedDict(
     "RemoveAllBackendsResponseTypeDef",
-    {"AppId": str, "Error": str, "JobId": str, "Operation": str, "Status": str},
+    {
+        "AppId": str,
+        "Error": str,
+        "JobId": str,
+        "Operation": str,
+        "Status": str,
+    },
     total=False,
 )
 
 RemoveBackendConfigResponseTypeDef = TypedDict(
-    "RemoveBackendConfigResponseTypeDef", {"Error": str}, total=False
+    "RemoveBackendConfigResponseTypeDef",
+    {
+        "Error": str,
+    },
+    total=False,
+)
+
+SettingsTypeDef = TypedDict(
+    "SettingsTypeDef",
+    {
+        "MfaTypes": List[MfaTypesElement],
+        "SmsMessage": str,
+    },
+    total=False,
+)
+
+SmsSettingsTypeDef = TypedDict(
+    "SmsSettingsTypeDef",
+    {
+        "SmsMessage": str,
+    },
+    total=False,
+)
+
+SocialProviderSettingsTypeDef = TypedDict(
+    "SocialProviderSettingsTypeDef",
+    {
+        "Facebook": "BackendAuthSocialProviderConfigTypeDef",
+        "Google": "BackendAuthSocialProviderConfigTypeDef",
+        "LoginWithAmazon": "BackendAuthSocialProviderConfigTypeDef",
+    },
+    total=False,
 )
 
 UpdateBackendAPIResponseTypeDef = TypedDict(
@@ -570,17 +626,68 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
     total=False,
 )
 
+UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "UpdateBackendAuthForgotPasswordConfigTypeDef",
+    {
+        "DeliveryMethod": DeliveryMethod,
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
+
+UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
+    "UpdateBackendAuthIdentityPoolConfigTypeDef",
+    {
+        "UnauthenticatedLogin": bool,
+    },
+    total=False,
+)
+
+UpdateBackendAuthMFAConfigTypeDef = TypedDict(
+    "UpdateBackendAuthMFAConfigTypeDef",
+    {
+        "MFAMode": MFAMode,
+        "Settings": "SettingsTypeDef",
+    },
+    total=False,
+)
+
+UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "UpdateBackendAuthOAuthConfigTypeDef",
+    {
+        "DomainPrefix": str,
+        "OAuthGrantType": OAuthGrantType,
+        "OAuthScopes": List[OAuthScopesElement],
+        "RedirectSignInURIs": List[str],
+        "RedirectSignOutURIs": List[str],
+        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
+    },
+    total=False,
+)
+
+UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "UpdateBackendAuthPasswordPolicyConfigTypeDef",
+    {
+        "AdditionalConstraints": List[AdditionalConstraintsElement],
+        "MinimumLength": float,
+    },
+    total=False,
+)
+
 _RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredUpdateBackendAuthResourceConfigTypeDef",
     {
         "AuthResources": AuthResources,
-        "Service": Service,
+        "Service": Literal["COGNITO"],
         "UserPoolConfigs": "UpdateBackendAuthUserPoolConfigTypeDef",
     },
 )
 _OptionalUpdateBackendAuthResourceConfigTypeDef = TypedDict(
     "_OptionalUpdateBackendAuthResourceConfigTypeDef",
-    {"IdentityPoolConfigs": "UpdateBackendAuthIdentityPoolConfigTypeDef"},
+    {
+        "IdentityPoolConfigs": "UpdateBackendAuthIdentityPoolConfigTypeDef",
+    },
     total=False,
 )
 
@@ -604,6 +711,17 @@ UpdateBackendAuthResponseTypeDef = TypedDict(
     total=False,
 )
 
+UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "UpdateBackendAuthUserPoolConfigTypeDef",
+    {
+        "ForgotPassword": "UpdateBackendAuthForgotPasswordConfigTypeDef",
+        "Mfa": "UpdateBackendAuthMFAConfigTypeDef",
+        "OAuth": "UpdateBackendAuthOAuthConfigTypeDef",
+        "PasswordPolicy": "UpdateBackendAuthPasswordPolicyConfigTypeDef",
+    },
+    total=False,
+)
+
 UpdateBackendConfigResponseTypeDef = TypedDict(
     "UpdateBackendConfigResponseTypeDef",
     {
